@@ -1,13 +1,13 @@
+pub use crate::compiled_program::*;
 pub use crate::compiler::{
-    compile, CaoIr, Card, CompilationError, CompilationErrorPayload, CompileOptions, Lane,
+    compile, CaoProgram, Card, CompilationError, CompilationErrorPayload, CompileOptions, Lane,
 };
 pub use crate::procedures::*;
-pub use crate::program::*;
 pub use crate::traits::*;
 pub use crate::value::*;
 pub use crate::{
     collections::key_map::Handle,
     subprogram_description,
     vm::{runtime::FieldTable, Vm},
-    InputString, NodeId, StrPointer, SubProgram, SubProgramType,
+    InputString, NodeId, StrPointer, SubProgramDescription, SubProgramType,
 };
